@@ -20,6 +20,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+import json
 import logging
 import os
 import platform
@@ -27,11 +28,15 @@ import shlex
 import struct
 import subprocess
 import sys
+import urllib2
 
 from not_so_tuf.compat import print_function, xrange_
+from not_so_tuf.utils import _version_string_to_tuple
 from not_so_tuf.version import __version__
 
 log = logging.getLogger(__name__)
+UPDATE = None
+update_message = None
 
 # If i didn't check for platform before
 # importing i'd get an ImportError
@@ -47,20 +52,45 @@ else:
 # Takes a string and adds it to the menu header along side
 # the app name.
 def app_header(*args, **kwargs):
+    global update_message
+    global UPDATE
     try:
         page = args[0]
     except IndexError:
-        page = ""
+        page = None
+    if UPDATE is None:
+        try:
+            version_ = urllib2.urlopen('https://s3-us-west-1.amazonaws.co'
+                                       'm/not-so-tuf/version.json').read()
+            version_data = json.loads(version_)
+            mac_latest = version_data['latest']['Not So TUF']['mac']
+            nix_latest = version_data['latest']['Not So TUF']['nix']
+            win_latest = version_data['latest']['Not So TUF']['win']
+            latest = sorted([_version_string_to_tuple(mac_latest),
+                            _version_string_to_tuple(nix_latest),
+                            _version_string_to_tuple(win_latest)])[-1]
+            cli_version = _version_string_to_tuple(__version__)
+            if cli_version < latest:
+                update_message = 'Update Available'
+                UPDATE = 'update available'
+            else:
+                update_message = None
+                UPDATE = 'update not available'
+        except:
+            update_message = None
+
     window_size = get_terminal_size()[0]
 
     def add_style():
         app = 'Not so TUF v{}'.format(__version__)
         top = '*' * window_size + '\n'
         bottom = '\n' + '*' * window_size + '\n'
-        if len(page) > 1:
+        if page is not None:
             header = app + ' - ' + page
         else:
-            header = app + page
+            header = app
+        if update_message is not None:
+            header = header + ' - ' + update_message
         header = header.center(window_size)
         msg = top + header + bottom
         return msg
