@@ -27,7 +27,7 @@ import shutil
 import sys
 
 from not_so_tuf.compat import print_function, urllib2
-from not_so_tuf.utils import _cwd, FROZEN, ChDir, ask_yes_no
+from not_so_tuf.utils import cwd_, FROZEN, ChDir, ask_yes_no
 from not_so_tuf.version import __version__
 
 
@@ -139,7 +139,7 @@ def path_fixer(path):
 def _directory_fixer(_dir):
     if _dir == 'Current Working Directory':
         log.debug('Using cwd for Current Working Directory')
-        _dir = _cwd
+        _dir = cwd_
     elif _dir.startswith('~'):
         log.debug('Expanding ~ to full user path')
         _dir = _dir[2:]
@@ -175,7 +175,7 @@ def install_client_package(test=False):
                     f.write('# Nothing to see here')
 
         else:
-            with ChDir(_cwd):
+            with ChDir(cwd_):
                 if os.path.exists(package_name):
                     shutil.rmtree(package_name, ignore_errors=True)
                 os.mkdir(package_name)
@@ -191,7 +191,7 @@ def write_client_config(config_object, test=False):
         if test:
             package_dir = 'tests/not_so_tuf'
         else:
-            package_dir = os.path.join(_cwd, 'not_so_tuf')
+            package_dir = os.path.join(cwd_, 'not_so_tuf')
         if getattr(config_object, 'UPDATE_URL', False):
             update_url = config_object.UPDATE_URL
         else:
