@@ -68,10 +68,15 @@ class ConfigException(STDError):
         super(ConfigException, self).__init__(*args, **kwargs)
 
 
+class FileCryptError(STDError):
+    """Raised for File Downloader exceptions"""
+    def __init__(self, *args, **kwargs):
+        super(FileCryptError, self).__init__(*args, **kwargs)
+
 class FileDownloaderError(STDError):
     """Raised for File Downloader exceptions"""
     def __init__(self, *args, **kwargs):
-        super(PackageHandlerError, self).__init__(*args, **kwargs)
+        super(FileDownloaderError, self).__init__(*args, **kwargs)
 
 
 class KeyHandlerError(STDError):
