@@ -69,27 +69,39 @@ class KeyHandler(object):
         # Private key setup
         self.private_key_name = obj.config.get('PRIVATE_KEY_NAME')
         if self.private_key_name is None:
+            # Using the app name for key name if not provided
             self.private_key_name = self.app_name + '.pem'
         if not self.private_key_name.endswith('.pem'):
+            # Adding extension if not already provided.
             self.private_key_name += '.pem'
 
         # Public key setup
         self.public_key_name = obj.config.get('PUBLIC_KEY_NAME')
         if self.public_key_name is None:
+            # Using app name for key name if not provided
             self.public_key_name = self.app_name + '.pub'
         if not self.public_key_name.endswith('.pub'):
+            # Adding extension if not already provided.
             self.public_key_name += '.pub'
 
         self.key_length = obj.config.get('KEY_LENGTH', 2048)
+        # Have to perform this check in case user passed None
+        # to KEY_LENGTH in config file
         if self.key_length is None:
             self.key_length = 2048
         self.version_file = os.path.join(self.data_dir, 'version.json')
         self.keys_dir = os.path.join(self.data_dir, 'keys')
         if not os.path.exists(self.keys_dir):
             log.info('Creating keys directory')
+            # Just in case folders got deleted before we start work :)
             os.makedirs(self.keys_dir)
 
-    def make_keys(self, overwrite=False, test=False):
+        # FileCrypt object
+        self.fc = None
+        # Set to true when running tests
+        self.test = False
+
+    def make_keys(self, overwrite=False):
         """Makes public and private keys for signing and verification
 
         Kwargs:
@@ -108,148 +120,83 @@ class KeyHandler(object):
         # This is the public key you must distribute with your
         # program and pass to rsa_verify.
         self.pubkey = (public_key_object.n, public_key_object.e)
-        self._write_keys_to_file(overwrite, test)
+        self._write_keys_to_file(overwrite)
 
-    def _write_keys_to_file(self, overwrite=False, test=False):
-        """Writes keys to disk
+    def sign_update(self):
+        """Signs version file with private key
 
-        Args:
-            overwrite (bool): Determines if existing keys are overwritten
-        """
-        # Writes the public and private keys to files
-        public = os.path.join(self.keys_dir, self.public_key_name)
-        private = os.path.join(self.keys_dir, self.private_key_name)
-        if os.path.exists(public) and os.path.exists(private):
-            if overwrite is False:
-                log.info('Cannot overwrite old key files.')
-                log.debug('Pass overwrite=True to make_keys to overwrite')
-                return
-            else:
-                log.warning('About to overwrite old keys')
-        log.info('Writing keys to file')
-        with open(private, 'w') as pri:
-            pri.write(self.privkey)
-        if test is False:
-            fc = FileCrypt(private)
-            fc.encrypt()
-        with open(public, 'w') as pub:
-            pub.write(str(self.pubkey))
-
-    def sign_update(self, test=False):
-        """Proxy method for :meth:`_load_private_key`, :meth:`_add_sig` &
+        Proxy method for :meth:`_load_private_key`, :meth:`_add_sig` &
         :meth:`_write_update_data`
         """
         # Loads private key
         # Loads version file to memory
         # Signs Version file
         # Writes version file back to disk
-        self._load_private_key(test)
+        self._load_private_key()
         self._add_sig()
         self._write_update_data()
 
-    # TODO: Search deafult locations for key file
-    def _find_private_key(self):
-        """Checks for private key
+    def get_public_key(self):
+        if not self._find_public_key():
+            raise KeyHandlerError(u'You do not have a public key',
+                                  expected=True)
+        public_key_path = os.path.join(self.keys_dir, self.public_key_name)
+        with open(public_key_path) as f:
+            pub_key_data = f.read()
+        return KeyHandler._pub_key_string_to_tuple(pub_key_data)
 
-        Returns:
-            (bool) Meanings::
+    def copy_decrypted_private_key(self):
+        """Copies decrypted private key."""
+        privkey = os.path.join(self.keys_dir, self.private_key_name)
+        log.debug('Private Key Path: {}'.format(privkey))
+        self.fc.new_file(privkey)
+        self.fc.decrypt()
+        shutil.copy(privkey, privkey + ' copy')
+        self.fc.encrypt()
 
-                True - Private key found
+    def print_keys_to_console(self):
+        """Prints public key and private key data to console"""
+        self._load_private_key()
+        print('Private Key:\n{}\n\n'.format(self.privkey))
+        self.print_public_key()
 
-                False - Private key not found
-        """
-        # Searches keys folder for private key to sign version file
-        path = os.path.join(self.keys_dir, self.private_key_name)
-        log.debug('private key path: {}'.format(path))
-        if os.path.exists(path + '.enc') or os.path.exists(path):
-            log.debug('Found private key')
-            return True
-        log.debug("Didn't find private key")
-        return False
+    def print_public_key(self):
+        """Prints public key data to console"""
+        public = os.path.join(self.keys_dir, self.public_key_name)
+        if os.path.exists(public):
+            with open(public) as f:
+                key = f.read()
+            print('Public Key:\n{}\n\n'.format(key))
+        else:
+            print('No Public Key Found')
 
-    def _find_public_key(self):
-        """Checks for public key
+    def print_key_names_to_console(self):
+        """Prints name of public and private key to console"""
+        print('Private Key:\n{}\n\n'.format(self.private_key_name))
+        print('Public Key:\n{}\n\n'.format(self.public_key_name))
 
-        Returns:
-            (bool) Meanings::
-
-                True - Private key found
-
-                False - Private key not found
-        """
-
-        path = os.path.join(self.keys_dir, self.public_key_name)
-        log.debug('Private key path: {}'.format(path))
-        if os.path.exists(path):
-            log.debug('Found public key')
-            return True
-        log.debug("Didn't find public key")
-        return False
-
-    def _load_private_key(self, test):
-        """Loads private key to memory
-
-        Raises:
-            KeyHandlerError: If private key cannot be found
-        """
+    def _load_private_key(self):
         # Loads private key
         log.info('Loading private key')
         if not self._find_private_key():
             raise KeyHandlerError(u"You don't have any keys",
                                   expected=True)
         privkey = os.path.join(self.keys_dir, self.private_key_name)
-        if test:
+
+        # If we are testing we can skip the decrypt set since nose
+        # cannot provide passwords.
+        if self.test:
             with open(privkey) as pk:
                 self.privkey = Crypto.PublicKey.RSA.importKey(pk.read())
             return
 
-        fc = FileCrypt(privkey)
-        fc.decrypt()
+        self.fc.new_file(privkey)
+        self.fc.decrypt()
         with open(privkey) as pk:
             self.privkey = Crypto.PublicKey.RSA.importKey(pk.read())
-        fc.encrypt()
-
-    def get_public_key(self):
-        if not self._find_public_key:
-            raise KeyHandlerError(u'You do not have a public key',
-                                  expected=True)
-        public_key = os.path.join(self.keys_dir, self.public_key_name)
-        with open(public_key) as f:
-            pub_key_data = f.read()
-        return KeyHandler._pub_key_string_to_tuple(pub_key_data)
-
-    @staticmethod
-    def _pub_key_string_to_tuple(x):
-        x = x.replace('(', '')
-        x = x.replace(')', '')
-        x = x.split(',')
-        return (long(x[0]), long(x[1]))
-
-    def _load_update_data(self):
-        """Loads version file
-
-        Returns:
-            (version data)
-
-        Raises:
-            KeyHandlerError:  Cannot find version file
-        """
-        # Loads version file into memory
-        log.info("Loading version file")
-        try:
-            log.debug('Version file path: {}'.format(self.version_file))
-            with open(self.version_file, 'r') as f:
-                update_data = json.loads(f.read())
-            log.debug('Version file loaded')
-            return update_data
-        except Exception as e:
-            log.error(e)
-            raise KeyHandlerError(u'Version file not found',
-                                  expected=True)
+        self.fc.encrypt()
 
     def _add_sig(self):
-        """Adds signature to version file
-        """
         # Adding new signature to version file
         log.info('Adding signature to version file...')
         if not self.privkey:
@@ -272,11 +219,6 @@ class KeyHandler(object):
         self.update_data = update_data
 
     def _write_update_data(self):
-        """Writes update data to disk
-
-        Raises:
-            KeyHandlerError: If signature wasn't added to version file
-        """
         # Write version file "with new sig" to disk
         log.info('Wrote version data')
         if self.update_data:
@@ -287,32 +229,78 @@ class KeyHandler(object):
             msg = u'You must sign update data first'
             raise KeyHandlerError(msg, expected=True)
 
-    def copy_decrypted_private_key(self, fc=None):
-        if fc is None:
-            fc = FileCrypt()
-        privkey = os.path.join(self.keys_dir, self.private_key_name)
-        log.debug('Private Key Path: {}'.format(privkey))
-        fc.new_file(privkey)
-        fc.decrypt()
-        shutil.copy(privkey, privkey + ' copy')
-        fc.encrypt()
+    def _write_keys_to_file(self, overwrite=False):
+        # Writes keys to disk
+        #
+        # Args:
+        #    overwrite (bool): Determines if existing keys are overwritten
 
-    def print_keys_to_console(self):
-        """Prints public key and private key data to console"""
-        print('Private Key:\n{}\n\n'.format(self.privkey))
-        print('Public Key:\n{}\n\n'.format(self.pubkey))
-
-    def print_public_key(self):
-        """Prints public key data to console"""
+        # Writes the public and private keys to files
         public = os.path.join(self.keys_dir, self.public_key_name)
-        if os.path.exists(public):
-            with open(public) as f:
-                key = f.read()
-            print('Public Key:\n{}'.format(key))
-        else:
-            print('No Public Key Found')
+        private = os.path.join(self.keys_dir, self.private_key_name)
+        if os.path.exists(public) and os.path.exists(private):
+            if overwrite is False:
+                log.info('Cannot overwrite old key files.')
+                log.debug('Pass overwrite=True to make_keys to overwrite')
+                return
+            else:
+                log.warning('About to overwrite old keys')
+        log.info('Writing keys to file')
+        with open(private, 'w') as pri:
+            pri.write(self.privkey)
+        if self.test is False:
+            self.fc.new_file(private)
+            self.fc.encrypt()
+        with open(public, 'w') as pub:
+            pub.write(str(self.pubkey))
 
-    def print_key_names_to_console(self):
-        """Prints name of public and private key to console"""
-        print('Private Key:\n{}\n\n'.format(self.private_key_name))
-        print('Public Key:\n{}\n\n'.format(self.public_key_name))
+    # TODO: Search deafult locations for key file
+    def _find_private_key(self):
+        # Searches keys folder for private key to sign version file
+        priv_key_path = os.path.join(self.keys_dir, self.private_key_name)
+        log.debug('private key path: {}'.format(priv_key_path))
+        if os.path.exists(priv_key_path + '.enc') or \
+                os.path.exists(priv_key_path):
+            log.debug('Found private key')
+            return True
+        log.debug("Didn't find private key")
+        return False
+
+    def _find_public_key(self):
+        # Searches keys folder for public key
+        public_key_path = os.path.join(self.keys_dir, self.public_key_name)
+        log.debug('Private key path: {}'.format(public_key_path))
+        if os.path.exists(public_key_path):
+            log.debug('Found public key')
+            return True
+        log.debug("Didn't find public key")
+        return False
+
+    @staticmethod
+    def _pub_key_string_to_tuple(x):
+        x = x.replace('(', '')
+        x = x.replace(')', '')
+        x = x.split(',')
+        return (long(x[0]), long(x[1]))
+
+    def _load_update_data(self):
+        # Loads version file into memory
+        log.info("Loading version file")
+        try:
+            log.debug('Version file path: {}'.format(self.version_file))
+            with open(self.version_file, 'r') as f:
+                update_data = json.loads(f.read())
+            log.debug('Version file loaded')
+            return update_data
+        except Exception as e:
+            log.error(e)
+            raise KeyHandlerError(u'Version file not found',
+                                  expected=True)
+
+    def _add_filecrypt(self, fc=None):
+        # Using a single file crypt object module wide.
+        # Helps with password timeout
+        if fc is None:
+            self.fc = FileCrypt()
+        else:
+            self.fc = fc
