@@ -36,11 +36,11 @@ FROZEN = getattr(sys, 'frozen', False)
 if FROZEN:
     log.debug('Running frozen')
     # we are running in a |PyInstaller| bundle
-    _cwd = os.path.dirname(sys.argv[0])
+    cwd_ = os.path.dirname(sys.argv[0])
 else:
     log.debug('Running thawed out.  e.g. not frozen :)')
     # we are running in a normal Python environment
-    _cwd = os.getcwd()
+    cwd_ = os.getcwd()
 
 if sys.platform == 'win32':
     platform_ = 'win'
